RouteOpenApi class
Web route that serves the OpenAPI specification
Constructors
- RouteOpenApi(Serverpod pod, {String title = 'API Documentation', String version = '1.0.0', String? description})
Properties
- asHandler → Handler
-
Returns this
HandlerObjectas aHandler.no setterinherited - description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String?
-
The virtual host this route will respond to.
finalinherited
-
methods
→ Set<
Method> -
The methods this route will respond to, i.e. HTTP get or post.
finalinherited
- path → String
-
The suffix path this route will respond to.
finalinherited
- pod → Serverpod
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- version → String
-
final
Methods
-
build(
Session session, Request request) → Future< WebWidget> -
Override this method to build your web widget from the current
sessionandrequest. -
call(
Request req) → Future< Result> -
Handles a call to this route, by extracting
Sessionfrom request and forwarding tohandleCall.inherited -
handleCall(
Session session, Request req) → FutureOr< Result> - Handles a call to this route.
-
injectIn(
RelicRouter router) → void -
Adds this handler to the given
routerwithMethod.getand path '/' Override to add differently.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited